@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 import itertools
 import operator
 from os.path import basename
@@ -6,7 +7,9 @@ from irods.models import Collection, DataObject
 from irods.data_object import iRODSDataObject
 from irods.meta import iRODSMetaCollection
 
+
 class iRODSCollection(object):
+
     def __init__(self, manager, result=None):
         self.manager = manager
         if result:
@@ -18,38 +21,42 @@ class iRODSCollection(object):
     @property
     def metadata(self):
         if not self._meta:
-            self._meta = iRODSMetaCollection(self.manager.sess.metadata, 
-                Collection, self.path)
+            self._meta = iRODSMetaCollection(self.manager.sess.metadata,
+                                             Collection, self.path)
         return self._meta
 
     @property
     def subcollections(self):
         query = self.manager.sess.query(Collection)\
             .filter(Collection.parent_name == self.path)
-        results = query.all()
+        results = query.get_results()
         return [iRODSCollection(self.manager, row) for row in results]
 
     @property
     def data_objects(self):
         query = self.manager.sess.query(DataObject)\
             .filter(DataObject.collection_id == self.id)
-        results = query.all()
-        grouped = itertools.groupby(results, operator.itemgetter(DataObject.id))
+        results = query.get_results()
+        grouped = itertools.groupby(
+            results, operator.itemgetter(DataObject.id))
         return [
-            iRODSDataObject(self.manager.sess.data_objects, self, list(replicas))
+            iRODSDataObject(
+                self.manager.sess.data_objects, self, list(replicas))
             for _, replicas in grouped
         ]
 
-    def remove(self, recurse=True, force=False, additional_flags={}):
+    def remove(self, recurse=True, force=False, additional_flags=None):
+        if additional_flags is None:
+            additional_flags = {}
         self.manager.remove(self.path, recurse, force, additional_flags)
-        
+
     def move(self, path):
-        pass
+        self.manager.move(self.path, path)
 
     def walk(self, topdown=True):
         """
         Collection tree generator.
-        
+
         For each subcollection in the directory tree, starting at the
         collection, yield a 3-tuple
         """
@@ -64,4 +71,4 @@ class iRODSCollection(object):
             yield (self, self.subcollections, self.data_objects)
 
     def __repr__(self):
-        return "<iRODSCollection %d %s>" % (self.id, self.name)
+        return "<iRODSCollection {id} {name}>".format(id=self.id, name=self.name.encode('utf-8'))
